=== added directory 'plugin/slave'
=== added file 'plugin/slave/applier.h'
--- plugin/slave/applier.h	1970-01-01 00:00:00 +0000
+++ plugin/slave/applier.h	2011-01-26 20:52:17 +0000
@@ -0,0 +1,57 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 David Shrewsbury
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_SLAVE_APPLIER_H
+#define PLUGIN_SLAVE_APPLIER_H
+
+#include "drizzled/plugin/daemon.h"
+#include <boost/thread.hpp>
+#include "plugin/slave/queue_manager.h"
+
+namespace slave
+{
+
+class Applier : public drizzled::plugin::Daemon
+{
+public:
+
+  Applier() : drizzled::plugin::Daemon("Replication Slave")
+  {
+    q_mgr.setCheckInterval(5);       /* TODO: Make this configurable? */
+    thread= boost::thread(&QueueManager::processQueue, &q_mgr);
+  }
+  
+  ~Applier()
+  {
+    printf("Slave services shutting down\n");
+    thread.interrupt();
+    thread.join();
+  }
+
+private:
+  QueueManager q_mgr;
+
+  /** Thread that will process the work queue */
+  boost::thread thread;
+};
+  
+} /* namespace slave */
+
+#endif /* PLUGIN_SLAVE_APPLIER_H */
\ No newline at end of file

=== added file 'plugin/slave/module.cc'
--- plugin/slave/module.cc	1970-01-01 00:00:00 +0000
+++ plugin/slave/module.cc	2011-01-26 20:52:17 +0000
@@ -0,0 +1,34 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 David Shrewsbury
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/slave/applier.h"
+#include "drizzled/plugin.h"
+
+using namespace drizzled;
+
+static int init(module::Context &context)
+{
+  context.add(new slave::Applier);
+
+  return 0;
+}
+
+DRIZZLE_PLUGIN(init, NULL, NULL);
\ No newline at end of file

=== added file 'plugin/slave/plugin.ini'
--- plugin/slave/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/slave/plugin.ini	2011-01-26 20:52:17 +0000
@@ -0,0 +1,7 @@
+[plugin]
+version=1.0
+author=David Shrewsbury
+title=Replication Slave
+description=Provides slave replication services
+sources= module.cc queue_manager.cc
+headers= applier.h queue_manager.h

=== added file 'plugin/slave/queue_manager.cc'
--- plugin/slave/queue_manager.cc	1970-01-01 00:00:00 +0000
+++ plugin/slave/queue_manager.cc	2011-01-26 20:52:17 +0000
@@ -0,0 +1,63 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 David Shrewsbury
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/slave/queue_manager.h"
+#include <boost/thread.hpp>
+#include "drizzled/message/transaction.pb.h"
+
+using namespace drizzled;
+
+namespace slave
+{
+
+void QueueManager::processQueue(void)
+{
+  boost::posix_time::seconds duration(checkInterval);
+
+  while (1)
+  {
+    {
+      boost::this_thread::disable_interruption di;
+      /* process the queue here */
+    }
+    
+    /*
+     * Interruptable only when not doing work (aka, sleeping)
+     */
+
+    try
+    {
+      boost::this_thread::sleep(duration);
+    }
+    catch (boost::thread_interrupted &)
+    {
+      return;
+    }
+  }
+}
+
+bool QueueManager::executeMessage(const message::Transaction &transaction)
+{
+  (void)transaction;
+  return true;
+}
+
+} /* namespace slave */
\ No newline at end of file

=== added file 'plugin/slave/queue_manager.h'
--- plugin/slave/queue_manager.h	1970-01-01 00:00:00 +0000
+++ plugin/slave/queue_manager.h	2011-01-26 20:52:17 +0000
@@ -0,0 +1,57 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 David Shrewsbury
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_SLAVE_QUEUE_MANAGER_H
+#define PLUGIN_SLAVE_QUEUE_MANAGER_H
+
+namespace drizzled
+{
+  namespace message
+  {
+    class Transaction;
+  }
+}
+
+namespace slave
+{
+
+class QueueManager
+{
+public:
+  /**
+   * Method to be supplied to an applier thread.
+   */
+  void processQueue(void);
+
+  void setCheckInterval(uint32_t seconds)
+  {
+    checkInterval= seconds;
+  }
+
+private:
+  /** Number of seconds to sleep between checking queue for messages */
+  uint32_t checkInterval;
+
+  bool executeMessage(const drizzled::message::Transaction &transaction);
+};
+
+} /* namespace slave */
+
+#endif /* PLUGIN_SLAVE_QUEUE_MANAGER_H */
\ No newline at end of file

